@@ -7,6 +7,6 @@ fn main() {
     }
     #[cfg(not(target_os = "windows"))]
     {
-        pkg_config::find_library("slirp").unwrap();
+        pkg_config::find_library("slirp >= 4.2.0").unwrap();
     }
 }
